| queryChEA3 | R Documentation |
#' Sends a gene list to the ChEA3 web service to identify enriched transcription factors using multiple evidence sources. The gene list should consist of HGNC-approved gene symbols.
queryChEA3(genes, query_name = "rChEA3_query", verbose = TRUE)
genes |
Character vector of HGNC gene symbols. |
query_name |
Optional query name (default: "rChEA3_query"). |
verbose |
Logical; if TRUE, print a grouped summary of available result collections (default: TRUE). |
A named list of data frames. Each element corresponds to a ChEA3 collection and contains an enrichment table with transcription factors and their statistics. The expected names are: c("Integrated–meanRank", "Integrated–topRank", "GTEx–Coexpression", "ARCHS4–Coexpression", "ENCODE–ChIP-seq", "ReMap–ChIP-seq", "Literature–ChIP-seq", "Enrichr–Queries").
results <- queryChEA3(c("SMAD9","FOXO1","MYC","STAT1","STAT3","SMAD3"))
names(results)
head(results[["Integrated--meanRank"]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.