Learn R Programming

rChEA3 (version 0.2.0)

displayTopN: Print the top-n rows for each ChEA3 collection

Description

Print the top-n rows for each ChEA3 collection

Usage

displayTopN(
  results,
  n = 10,
  columns = c("Rank", "TF", "Scaled Rank", "Set_name", "Intersect", "Score",
    "FET p-value", "FDR", "Odds Ratio")
)

Value

(Invisibly) a named list of data frames, each truncated to the first n rows (and columns if provided).

Arguments

results

A named list of data frames (the output of queryChEA3()).

n

Number of rows to show per table (default: 10).

columns

Optional character vector of column names to display (keeps intersection with what's present in each data frame).

Examples

Run this code
# \donttest{
    genes <- c("TP53", "MYC", "STAT3", "FOXO1", "BRCA1")
    results <- queryChEA3(genes, verbose = FALSE)

    # Display top 10 TFs from each collection
    displayTopN(results)

    # Display only top 5 with specific columns
    displayTopN(results, n = 5, columns = c("Rank", "TF", "Score", "FDR"))
# }

Run the code above in your browser using DataLab